==> mysql-8.0_8.0.36.orig.tar.gz: mysql-8.0.36/router/src/routing/src/sql_lexer_error.h <==
/*
  Copyright (c) 2022, 2023, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef ROUTING_SQL_LEXER_ERROR_INCLUDED
#define ROUTING_SQL_LEXER_ERROR_INCLUDED

#include "m_ctype.h"  // my_charset_...

class THD;

inline void warn_on_deprecated_charset(THD * /* thd */,
                                       const CHARSET_INFO * /* cs */,
                                       const char * /* alias */,
                                       const char * /* option */ = nullptr) {}

inline void warn_on_deprecated_collation(THD * /* thd */,
                                         const CHARSET_INFO * /* collation */,
                                         const char * /* option */ = nullptr) {}

inline void push_deprecated_warn(THD * /* thd */, const char * /* old_syntax */,
                                 const char * /* new_syntax */) {}

inline void push_deprecated_warn_no_replacement(THD * /* thd */,
                                                const char * /* old_syntax */) {
}
#endif

==> mysql-8.0_8.0.43.orig.tar.gz: mysql-8.0.43/router/src/routing/src/sql_lexer_error.h <==
/*
  Copyright (c) 2022, 2025, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef ROUTING_SQL_LEXER_ERROR_INCLUDED
#define ROUTING_SQL_LEXER_ERROR_INCLUDED

#include "m_ctype.h"  // my_charset_...

class THD;

inline void warn_on_deprecated_charset(THD * /* thd */,
                                       const CHARSET_INFO * /* cs */,
                                       const char * /* alias */,
                                       const char * /* option */ = nullptr) {}

inline void warn_on_deprecated_collation(THD * /* thd */,
                                         const CHARSET_INFO * /* collation */,
                                         const char * /* option */ = nullptr) {}

inline void push_deprecated_warn(THD * /* thd */, const char * /* old_syntax */,
                                 const char * /* new_syntax */) {}

inline void push_deprecated_warn_no_replacement(THD * /* thd */,
                                                const char * /* old_syntax */) {
}
#endif
